==> defi-services-lib-1.0.4.tar.gz: defi-services-lib-1.0.4/src/defi_services/lending_pools/lending_pools_info/ethereum/aave_v2_eth.py <==
AAVE_V2_ETH = {
    "address": "0x7d2768dE32b0b80b7a3454c06BdAc94A69DDc7A9",
    "name": "Aave V2 Lending Pool",
    "rewardToken": "0x7Fc66500c84A76Ad7e9c93437bFc5Ac33E2DDaE9",
    "stakedIncentiveAddress": '0x83D055D382f25e6793099713505c68a5C7535a35',
    "oracleAddress": "0xA50ba011c48153De246E5192C8f9258A2ba79Ca9",
    "type": "LENDING_POOL",
    "reservesList": {
        "0xdac17f958d2ee523a2206206994597c13d831ec7": {
            "tToken": "0x3ed3b47dd13ec9a98b44e6204a523e766b225811",
            "dToken": "0x531842cebbdd378f8ee36d171d6cc9c4fcf475ec",
            "sdToken": "0xe91d55ab2240594855abd11b3faae801fd4c4687",
            "liquidationThreshold": 0.0
        },
        "0x2260fac5e5542a773aa44fbcfedf7c193bc2c599": {
            "tToken": "0x9ff58f4ffb29fa2266ab25e75e2a8b3503311656",
            "dToken": "0x9c39809dec7f95f5e0713634a4d0701329b3b4d2",
            "sdToken": "0x51b039b9afe64b78758f8ef091211b5387ea717c",
            "liquidationThreshold": 0.82
        },
        "0xc02aaa39b223fe8d0a0e5c4f27ead9083c756cc2": {
            "tToken": "0x030ba81f1c18d280636f32af80b9aad02cf0854e",
            "dToken": "0xf63b34710400cad3e044cffdcab00a0f32e33ecf",
            "sdToken": "0x4e977830ba4bd783c0bb7f15d3e243f73ff57121",
            "liquidationThreshold": 0.86
        },
        "0x0bc529c00c6401aef6d220be8c6ea1667f6ad93e": {
            "tToken": "0x5165d24277cd063f5ac44efd447b27025e888f37",
            "dToken": "0x7ebd09022be45ad993baa1cec61166fcc8644d97",
            "sdToken": "0xca823f78c2dd38993284bb42ba9b14152082f7bd",
            "liquidationThreshold": 0.65
        },
        "0xe41d2489571d322189246dafa5ebde1f4699f498": {
            "tToken": "0xdf7ff54aacacbff42dfe29dd6144a69b629f8c9e",
            "dToken": "0x85791d117a392097590bded3bd5abb8d5a20491a",
            "sdToken": "0x071b4323a24e73a5afeebe34118cd21b8faaf7c3",
            "liquidationThreshold": 0.65
        },
        "0x1f9840a85d5af5bf1d1762f925bdaddc4201f984": {
            "tToken": "0xb9d7cb55f463405cdfbe4e90a6d2df01c2b92bf1",
            "dToken": "0x5bdb050a92cadccfcdcccbfc17204a1c9cc0ab73",
            "sdToken": "0xd939f7430dc8d5a427f156de1012a56c18acb6aa",
            "liquidationThreshold": 0.77
        },
        "0x7fc66500c84a76ad7e9c93437bfc5ac33e2ddae9": {
            "tToken": "0xffc97d72e13e01096502cb8eb52dee56f74dad7b",
            "dToken": "0xf7dba49d571745d9d7fcb56225b05bea803ebf3c",
            "sdToken": "0x079d6a3e844bcecf5720478a718edb6575362c5f",
            "liquidationThreshold": 0.73
        },
        "0x0d8775f648430679a709e98d2b0cb6250d2887ef": {
            "tToken": "0x05ec93c0365baaeabf7aeffb0972ea7ecdd39cf1",
            "dToken": "0xfc218a6dfe6901cb34b1a5281fc6f1b8e7e56877",
            "sdToken": "0x277f8676facf4daa5a6ea38ba511b7f65aa02f9f",
            "liquidationThreshold": 0.7
        },
        "0x4fabb145d64652a948d72533023f6e7a623c7c53": {
            "tToken": "0xa361718326c15715591c299427c62086f69923d9",
            "dToken": "0xba429f7011c9fa04cdd46a2da24dc0ff0ac6099c",
            "sdToken": "0x4a7a63909a72d268b1d8a93a9395d098688e0e5c",
            "liquidationThreshold": 0.0
        },
        "0x6b175474e89094c44da98b954eedeac495271d0f": {
            "tToken": "0x028171bca77440897b824ca71d1c56cac55b68a3",
            "dToken": "0x6c3c78838c761c6ac7be9f59fe808ea2a6e4379d",
            "sdToken": "0x778a13d3eeb110a4f7bb6529f99c000119a08e92",
            "liquidationThreshold": 0.87
        },
        "0xf629cbd94d3791c9250152bd8dfbdf380e2a3b9c": {
            "tToken": "0xac6df26a590f08dcc95d5a4705ae8abbc88509ef",
            "dToken": "0x38995f292a6e31b78203254fe1cdd5ca1010a446",
            "sdToken": "0x943dcca156b5312aa24c1a08769d67fece4ac14c",
            "liquidationThreshold": 0.67
        },
        "0xdd974d5c2e2928dea5f71b9825b8b646686bd200": {
            "tToken": "0x39c6b3e42d6a679d7d776778fe880bc9487c2eda",
            "dToken": "0x6b05d1c608015ccb8e205a690cb86773a96f39f1",
            "sdToken": "0x9915dfb872778b2890a117da1f35f335eb06b54f",
            "liquidationThreshold": 0.7
        },
        "0x514910771af9ca656af840dff83e8264ecf986ca": {
            "tToken": "0xa06bc25b5805d5f8d82847d191cb4af5a3e873e0",
            "dToken": "0x0b8f12b1788bfde65aa1ca52e3e9f3ba401be16d",
            "sdToken": "0xfb4aec4cc858f2539ebd3d37f2a43eae5b15b98a",
            "liquidationThreshold": 0.83
        },
        "0x0f5d2fb29fb7d3cfee444a200298f468908cc942": {
            "tToken": "0xa685a61171bb30d4072b338c80cb7b2c865c873e",
            "dToken": "0x0a68976301e46ca6ce7410db28883e309ea0d352",
            "sdToken": "0xd86c74ea2224f4b8591560652b50035e4e5c0a3b",
            "liquidationThreshold": 0.75
        },
        "0x9f8f72aa9304c8b593d555f12ef6589cc3a579a2": {
            "tToken": "0xc713e5e149d5d0715dcd1c156a020976e7e56b88",
            "dToken": "0xba728ead5e496be00dcf66f650b6d7758ecb50f8",
            "sdToken": "0xc01c8e4b12a89456a9fd4e4e75b72546bf53f0b5",
            "liquidationThreshold": 0.64
        },
        "0x408e41876cccdc0f92210600ef50372656052a38": {
            "tToken": "0xcc12abe4ff81c9378d670de1b57f8e0dd228d77a",
            "dToken": "0xcd9d82d33bd737de215cdac57fe2f7f04df77fe0",
            "sdToken": "0x3356ec1efa75d9d150da1ec7d944d9edf73703b7",
            "liquidationThreshold": 0.6
        },
        "0xc011a73ee8576fb46f5e1c5751ca3b9fe0af2a6f": {
            "tToken": "0x35f6b052c598d933d69a4eec4d04c73a191fe6c2",
            "dToken": "0x267eb8cf715455517f9bd5834aeae3cea1ebdbd8",
            "sdToken": "0x8575c8ae70bdb71606a53aea1c6789cb0fbf3166",
            "liquidationThreshold": 0.62
        },
        "0x57ab1ec28d129707052df4df418d58a2d46d5f51": {
            "tToken": "0x6c5024cd4f8a59110119c56f8933403a539555eb",
            "dToken": "0xdc6a3ab17299d9c2a412b0e0a4c1f55446ae0817",
            "sdToken": "0x30b0f7324fedf89d8eff397275f8983397efe4af",
            "liquidationThreshold": 0.0
        },
        "0x0000000000085d4780b73119b644ae5ecd22b376": {
            "tToken": "0x101cc05f4a51c0319f570d5e146a8c625198e636",
            "dToken": "0x01c0eb1f8c6f1c1bf74ae028697ce7aa2a8b0e92",
            "sdToken": "0x7f38d60d94652072b2c44a18c0e14a481ec3c0dd",
            "liquidationThreshold": 0.825
        },
        "0xa0b86991c6218b36c1d19d4a2e9eb0ce3606eb48": {
            "tToken": "0xbcca60bb61934080951369a648fb03df4f96263c",
            "dToken": "0x619beb58998ed2278e08620f97007e1116d5d25b",
            "sdToken": "0xe4922afab0bbadd8ab2a88e0c79d884ad337fca6",
            "liquidationThreshold": 0.875
        },
        "0xd533a949740bb3306d119cc777fa900ba034cd52": {
            "tToken": "0x8dae6cb04688c62d939ed9b68d32bc62e49970b1",
            "dToken": "0x00ad8ebf64f141f1c81e9f8f792d3d1631c6c684",
            "sdToken": "0x9288059a74f589c919c7cf1db433251cdfeb874b",
            "liquidationThreshold": 0.58
        },
        "0x056fd409e1d7a124bd7017459dfea2f387b6d5cd": {
            "tToken": "0xd37ee7e4f452c6638c96536e68090de8cbcdb583",
            "dToken": "0x279af5b99540c1a3a7e3cdd326e19659401ef99e",
            "sdToken": "0xf8ac64ec6ff8e0028b37eb89772d21865321bce0",
            "liquidationThreshold": 0.0
        },
        "0xba100000625a3754423978a60c9317c58a424e3d": {
            "tToken": "0x272f97b7a56a387ae942350bbc7df5700f8a4576",
            "dToken": "0x13210d4fe0d5402bd7ecbc4b5bc5cfca3b71adb0",
            "sdToken": "0xe569d31590307d05da3812964f1edd551d665a0b",
            "liquidationThreshold": 0.7
        },
        "0x8798249c2e607446efb7ad49ec89dd1865ff4272": {
            "tToken": "0xf256cc7847e919fac9b808cc216cac87ccf2f47a",
            "dToken": "0xfafedf95e21184e3d880bd56d4806c4b8d31c69a",
            "sdToken": "0x73bfb81d7dba75c904f430ea8bae82db0d41187b",
            "liquidationThreshold": 0.65
        },
        "0xd5147bc8e386d91cc5dbe72099dac6c9b99276f5": {
            "tToken": "0x514cd6756ccbe28772d4cb81bc3156ba9d1744aa",
            "dToken": "0x348e2ebd5e962854871874e444f4122399c02755",
            "sdToken": "0xcaad05c49e14075077915cb5c820eb3245afb950",
            "liquidationThreshold": 0.0
        },
        "0x03ab458634910aad20ef5f1c8ee96f1d6ac54919": {
            "tToken": "0xc9bc48c72154ef3e5425641a3c747242112a46af",
            "dToken": "0xb5385132ee8321977fff44b60cde9fe9ab0b4e6b",
            "sdToken": "0x9c72b8476c33ae214ee3e8c20f0bc28496a62032",
            "liquidationThreshold": 0.0
        },
        "0xd46ba6d942050d489dbd938a2c909a5d5039a161": {
            "tToken": "0x1e6bb68acec8fefbd87d192be09bb274170a0548",
            "dToken": "0xf013d90e4e4e3baf420dfea60735e75dbd42f1e1",
            "sdToken": "0x18152c9f77dadc737006e9430db913159645fa87",
            "liquidationThreshold": 0.0
        },
        "0x8e870d67f660d95d5be530380d0ec0bd388289e1": {
            "tToken": "0x2e8f4bdbe3d47d7d7de490437aea9915d930f1a3",
            "dToken": "0xfdb93b3b10936cf81fa59a02a7523b6e2149b2b7",
            "sdToken": "0x2387119bc85a74e0bbcbe190d80676cb16f10d4f",
            "liquidationThreshold": 0.0
        },
        "0x1494ca1f11d487c2bbe4543e90080aeba4ba3c2b": {
            "tToken": "0x6f634c6135d2ebd550000ac92f494f9cb8183dae",
            "dToken": "0x4ddff5885a67e4effec55875a3977d7e60f82ae0",
            "sdToken": "0xa3953f07f389d719f99fc378ebdb9276177d8a6e",
            "liquidationThreshold": 0.7
        },
        "0x853d955acef822db058eb8505911ed77f175b99e": {
            "tToken": "0xd4937682df3c8aef4fe912a96a74121c0829e664",
            "dToken": "0xfe8f19b17ffef0fdbfe2671f248903055afaa8ca",
            "sdToken": "0x3916e3b6c84b161df1b2733dffc9569a1da710c2",
            "liquidationThreshold": 0.0
        },
        "0x956f47f50a910163d8bf957cf5846d573e7f87ca": {
            "tToken": "0x683923db55fead99a79fa01a27eec3cb19679cc3",
            "dToken": "0xc2e10006accab7b45d9184fcf5b7ec7763f5baae",
            "sdToken": "0xd89cf9e8a858f8b4b31faf793505e112d6c17449",
            "liquidationThreshold": 0.75
        },
        "0xae7ab96520de3a18e5e111b5eaab095312d7fe84": {
            "tToken": "0x1982b2f5814301d4e9a8b0201555376e62f82428",
            "dToken": "0xa9deac9f00dc4310c35603fcd9d34d1a750f81db",
            "sdToken": "0x66457616dd8489df5d0afd8678f4a260088aaf55",
            "liquidationThreshold": 0.83
        },
        "0xc18360217d8f7ab5e7c516566761ea12ce7f9d72": {
            "tToken": "0x9a14e23a58edf4efdcb360f68cd1b95ce2081a2f",
            "dToken": "0x176808047cc9b7a2c9ae202c593ed42ddd7c0d13",
            "sdToken": "0x34441ffd1948e49dc7a607882d0c38efd0083815",
            "liquidationThreshold": 0.57
        },
        "0xa693b19d2931d498c5b318df961919bb4aee87a5": {
            "tToken": "0xc2e2152647f4c26028482efaf64b2aa28779efc4",
            "dToken": "0xaf32001cf2e66c4c3af4205f6ea77112aa4160fe",
            "sdToken": "0x7fdbfb0412700d94403c42ca3caeeea183f07b26",
            "liquidationThreshold": 0.0
        },
        "0x4e3fbd56cd56c3e72c1403e103b45db9da5b9d2b": {
            "tToken": "0x952749e07d7157bb9644a894dfaf3bad5ef6d918",
            "dToken": "0x4ae5e4409c6dbc84a00f9f89e4ba096603fb7d50",
            "sdToken": "0xb01eb1ce1da06179136d561766fc2d609c5f55eb",
            "liquidationThreshold": 0.45
        },
        "0x111111111117dc0aa78b770fa6a738034120c302": {
            "tToken": "0xb29130cbcc3f791f077eade0266168e808e5151e",
            "dToken": "0xd7896c1b9b4455aff31473908eb15796ad2295da",
            "sdToken": "0x1278d6ed804d59d2d18a5aa5638dfd591a79af0a",
            "liquidationThreshold": 0.5
        },
        "0x5f98805a4e8be255a32880fdec7f6728c6568ba0": {
            "tToken": "0xce1871f791548600cb59efbeffc9c38719142079",
            "dToken": "0x411066489ab40442d6fc215ad7c64224120d33f2",
            "sdToken": "0x39f010127274b2dbdb770b45e1de54d974974526",
            "liquidationThreshold": 0.0
        }
    }
}

==> defi-services-lib-1.0.5.tar.gz: defi-services-lib-1.0.5/src/defi_services/lending_pools/lending_pools_info/ethereum/aave_v2_eth.py <==
AAVE_V2_ETH = {
    "address": "0x7d2768de32b0b80b7a3454c06bdac94a69ddc7a9",
    "name": "Aave V2 Lending Pool",
    "rewardToken": "0x7fc66500c84a76ad7e9c93437bfc5ac33e2ddae9",
    "stakedIncentiveAddress": '0x83d055d382f25e6793099713505c68a5c7535a35',
    "oracleAddress": "0xa50ba011c48153de246e5192c8f9258a2ba79ca9",
    "type": "LENDING_POOL",
    "reservesList": {
        "0xdac17f958d2ee523a2206206994597c13d831ec7": {
            "tToken": "0x3ed3b47dd13ec9a98b44e6204a523e766b225811",
            "dToken": "0x531842cebbdd378f8ee36d171d6cc9c4fcf475ec",
            "sdToken": "0xe91d55ab2240594855abd11b3faae801fd4c4687",
            "liquidationThreshold": 0.0
        },
        "0x2260fac5e5542a773aa44fbcfedf7c193bc2c599": {
            "tToken": "0x9ff58f4ffb29fa2266ab25e75e2a8b3503311656",
            "dToken": "0x9c39809dec7f95f5e0713634a4d0701329b3b4d2",
            "sdToken": "0x51b039b9afe64b78758f8ef091211b5387ea717c",
            "liquidationThreshold": 0.82
        },
        "0xc02aaa39b223fe8d0a0e5c4f27ead9083c756cc2": {
            "tToken": "0x030ba81f1c18d280636f32af80b9aad02cf0854e",
            "dToken": "0xf63b34710400cad3e044cffdcab00a0f32e33ecf",
            "sdToken": "0x4e977830ba4bd783c0bb7f15d3e243f73ff57121",
            "liquidationThreshold": 0.86
        },
        "0x0bc529c00c6401aef6d220be8c6ea1667f6ad93e": {
            "tToken": "0x5165d24277cd063f5ac44efd447b27025e888f37",
            "dToken": "0x7ebd09022be45ad993baa1cec61166fcc8644d97",
            "sdToken": "0xca823f78c2dd38993284bb42ba9b14152082f7bd",
            "liquidationThreshold": 0.65
        },
        "0xe41d2489571d322189246dafa5ebde1f4699f498": {
            "tToken": "0xdf7ff54aacacbff42dfe29dd6144a69b629f8c9e",
            "dToken": "0x85791d117a392097590bded3bd5abb8d5a20491a",
            "sdToken": "0x071b4323a24e73a5afeebe34118cd21b8faaf7c3",
            "liquidationThreshold": 0.65
        },
        "0x1f9840a85d5af5bf1d1762f925bdaddc4201f984": {
            "tToken": "0xb9d7cb55f463405cdfbe4e90a6d2df01c2b92bf1",
            "dToken": "0x5bdb050a92cadccfcdcccbfc17204a1c9cc0ab73",
            "sdToken": "0xd939f7430dc8d5a427f156de1012a56c18acb6aa",
            "liquidationThreshold": 0.77
        },
        "0x7fc66500c84a76ad7e9c93437bfc5ac33e2ddae9": {
            "tToken": "0xffc97d72e13e01096502cb8eb52dee56f74dad7b",
            "dToken": "0xf7dba49d571745d9d7fcb56225b05bea803ebf3c",
            "sdToken": "0x079d6a3e844bcecf5720478a718edb6575362c5f",
            "liquidationThreshold": 0.73
        },
        "0x0d8775f648430679a709e98d2b0cb6250d2887ef": {
            "tToken": "0x05ec93c0365baaeabf7aeffb0972ea7ecdd39cf1",
            "dToken": "0xfc218a6dfe6901cb34b1a5281fc6f1b8e7e56877",
            "sdToken": "0x277f8676facf4daa5a6ea38ba511b7f65aa02f9f",
            "liquidationThreshold": 0.7
        },
        "0x4fabb145d64652a948d72533023f6e7a623c7c53": {
            "tToken": "0xa361718326c15715591c299427c62086f69923d9",
            "dToken": "0xba429f7011c9fa04cdd46a2da24dc0ff0ac6099c",
            "sdToken": "0x4a7a63909a72d268b1d8a93a9395d098688e0e5c",
            "liquidationThreshold": 0.0
        },
        "0x6b175474e89094c44da98b954eedeac495271d0f": {
            "tToken": "0x028171bca77440897b824ca71d1c56cac55b68a3",
            "dToken": "0x6c3c78838c761c6ac7be9f59fe808ea2a6e4379d",
            "sdToken": "0x778a13d3eeb110a4f7bb6529f99c000119a08e92",
            "liquidationThreshold": 0.87
        },
        "0xf629cbd94d3791c9250152bd8dfbdf380e2a3b9c": {
            "tToken": "0xac6df26a590f08dcc95d5a4705ae8abbc88509ef",
            "dToken": "0x38995f292a6e31b78203254fe1cdd5ca1010a446",
            "sdToken": "0x943dcca156b5312aa24c1a08769d67fece4ac14c",
            "liquidationThreshold": 0.67
        },
        "0xdd974d5c2e2928dea5f71b9825b8b646686bd200": {
            "tToken": "0x39c6b3e42d6a679d7d776778fe880bc9487c2eda",
            "dToken": "0x6b05d1c608015ccb8e205a690cb86773a96f39f1",
            "sdToken": "0x9915dfb872778b2890a117da1f35f335eb06b54f",
            "liquidationThreshold": 0.7
        },
        "0x514910771af9ca656af840dff83e8264ecf986ca": {
            "tToken": "0xa06bc25b5805d5f8d82847d191cb4af5a3e873e0",
            "dToken": "0x0b8f12b1788bfde65aa1ca52e3e9f3ba401be16d",
            "sdToken": "0xfb4aec4cc858f2539ebd3d37f2a43eae5b15b98a",
            "liquidationThreshold": 0.83
        },
        "0x0f5d2fb29fb7d3cfee444a200298f468908cc942": {
            "tToken": "0xa685a61171bb30d4072b338c80cb7b2c865c873e",
            "dToken": "0x0a68976301e46ca6ce7410db28883e309ea0d352",
            "sdToken": "0xd86c74ea2224f4b8591560652b50035e4e5c0a3b",
            "liquidationThreshold": 0.75
        },
        "0x9f8f72aa9304c8b593d555f12ef6589cc3a579a2": {
            "tToken": "0xc713e5e149d5d0715dcd1c156a020976e7e56b88",
            "dToken": "0xba728ead5e496be00dcf66f650b6d7758ecb50f8",
            "sdToken": "0xc01c8e4b12a89456a9fd4e4e75b72546bf53f0b5",
            "liquidationThreshold": 0.64
        },
        "0x408e41876cccdc0f92210600ef50372656052a38": {
            "tToken": "0xcc12abe4ff81c9378d670de1b57f8e0dd228d77a",
            "dToken": "0xcd9d82d33bd737de215cdac57fe2f7f04df77fe0",
            "sdToken": "0x3356ec1efa75d9d150da1ec7d944d9edf73703b7",
            "liquidationThreshold": 0.6
        },
        "0xc011a73ee8576fb46f5e1c5751ca3b9fe0af2a6f": {
            "tToken": "0x35f6b052c598d933d69a4eec4d04c73a191fe6c2",
            "dToken": "0x267eb8cf715455517f9bd5834aeae3cea1ebdbd8",
            "sdToken": "0x8575c8ae70bdb71606a53aea1c6789cb0fbf3166",
            "liquidationThreshold": 0.62
        },
        "0x57ab1ec28d129707052df4df418d58a2d46d5f51": {
            "tToken": "0x6c5024cd4f8a59110119c56f8933403a539555eb",
            "dToken": "0xdc6a3ab17299d9c2a412b0e0a4c1f55446ae0817",
            "sdToken": "0x30b0f7324fedf89d8eff397275f8983397efe4af",
            "liquidationThreshold": 0.0
        },
        "0x0000000000085d4780b73119b644ae5ecd22b376": {
            "tToken": "0x101cc05f4a51c0319f570d5e146a8c625198e636",
            "dToken": "0x01c0eb1f8c6f1c1bf74ae028697ce7aa2a8b0e92",
            "sdToken": "0x7f38d60d94652072b2c44a18c0e14a481ec3c0dd",
            "liquidationThreshold": 0.825
        },
        "0xa0b86991c6218b36c1d19d4a2e9eb0ce3606eb48": {
            "tToken": "0xbcca60bb61934080951369a648fb03df4f96263c",
            "dToken": "0x619beb58998ed2278e08620f97007e1116d5d25b",
            "sdToken": "0xe4922afab0bbadd8ab2a88e0c79d884ad337fca6",
            "liquidationThreshold": 0.875
        },
        "0xd533a949740bb3306d119cc777fa900ba034cd52": {
            "tToken": "0x8dae6cb04688c62d939ed9b68d32bc62e49970b1",
            "dToken": "0x00ad8ebf64f141f1c81e9f8f792d3d1631c6c684",
            "sdToken": "0x9288059a74f589c919c7cf1db433251cdfeb874b",
            "liquidationThreshold": 0.58
        },
        "0x056fd409e1d7a124bd7017459dfea2f387b6d5cd": {
            "tToken": "0xd37ee7e4f452c6638c96536e68090de8cbcdb583",
            "dToken": "0x279af5b99540c1a3a7e3cdd326e19659401ef99e",
            "sdToken": "0xf8ac64ec6ff8e0028b37eb89772d21865321bce0",
            "liquidationThreshold": 0.0
        },
        "0xba100000625a3754423978a60c9317c58a424e3d": {
            "tToken": "0x272f97b7a56a387ae942350bbc7df5700f8a4576",
            "dToken": "0x13210d4fe0d5402bd7ecbc4b5bc5cfca3b71adb0",
            "sdToken": "0xe569d31590307d05da3812964f1edd551d665a0b",
            "liquidationThreshold": 0.7
        },
        "0x8798249c2e607446efb7ad49ec89dd1865ff4272": {
            "tToken": "0xf256cc7847e919fac9b808cc216cac87ccf2f47a",
            "dToken": "0xfafedf95e21184e3d880bd56d4806c4b8d31c69a",
            "sdToken": "0x73bfb81d7dba75c904f430ea8bae82db0d41187b",
            "liquidationThreshold": 0.65
        },
        "0xd5147bc8e386d91cc5dbe72099dac6c9b99276f5": {
            "tToken": "0x514cd6756ccbe28772d4cb81bc3156ba9d1744aa",
            "dToken": "0x348e2ebd5e962854871874e444f4122399c02755",
            "sdToken": "0xcaad05c49e14075077915cb5c820eb3245afb950",
            "liquidationThreshold": 0.0
        },
        "0x03ab458634910aad20ef5f1c8ee96f1d6ac54919": {
            "tToken": "0xc9bc48c72154ef3e5425641a3c747242112a46af",
            "dToken": "0xb5385132ee8321977fff44b60cde9fe9ab0b4e6b",
            "sdToken": "0x9c72b8476c33ae214ee3e8c20f0bc28496a62032",
            "liquidationThreshold": 0.0
        },
        "0xd46ba6d942050d489dbd938a2c909a5d5039a161": {
            "tToken": "0x1e6bb68acec8fefbd87d192be09bb274170a0548",
            "dToken": "0xf013d90e4e4e3baf420dfea60735e75dbd42f1e1",
            "sdToken": "0x18152c9f77dadc737006e9430db913159645fa87",
            "liquidationThreshold": 0.0
        },
        "0x8e870d67f660d95d5be530380d0ec0bd388289e1": {
            "tToken": "0x2e8f4bdbe3d47d7d7de490437aea9915d930f1a3",
            "dToken": "0xfdb93b3b10936cf81fa59a02a7523b6e2149b2b7",
            "sdToken": "0x2387119bc85a74e0bbcbe190d80676cb16f10d4f",
            "liquidationThreshold": 0.0
        },
        "0x1494ca1f11d487c2bbe4543e90080aeba4ba3c2b": {
            "tToken": "0x6f634c6135d2ebd550000ac92f494f9cb8183dae",
            "dToken": "0x4ddff5885a67e4effec55875a3977d7e60f82ae0",
            "sdToken": "0xa3953f07f389d719f99fc378ebdb9276177d8a6e",
            "liquidationThreshold": 0.7
        },
        "0x853d955acef822db058eb8505911ed77f175b99e": {
            "tToken": "0xd4937682df3c8aef4fe912a96a74121c0829e664",
            "dToken": "0xfe8f19b17ffef0fdbfe2671f248903055afaa8ca",
            "sdToken": "0x3916e3b6c84b161df1b2733dffc9569a1da710c2",
            "liquidationThreshold": 0.0
        },
        "0x956f47f50a910163d8bf957cf5846d573e7f87ca": {
            "tToken": "0x683923db55fead99a79fa01a27eec3cb19679cc3",
            "dToken": "0xc2e10006accab7b45d9184fcf5b7ec7763f5baae",
            "sdToken": "0xd89cf9e8a858f8b4b31faf793505e112d6c17449",
            "liquidationThreshold": 0.75
        },
        "0xae7ab96520de3a18e5e111b5eaab095312d7fe84": {
            "tToken": "0x1982b2f5814301d4e9a8b0201555376e62f82428",
            "dToken": "0xa9deac9f00dc4310c35603fcd9d34d1a750f81db",
            "sdToken": "0x66457616dd8489df5d0afd8678f4a260088aaf55",
            "liquidationThreshold": 0.83
        },
        "0xc18360217d8f7ab5e7c516566761ea12ce7f9d72": {
            "tToken": "0x9a14e23a58edf4efdcb360f68cd1b95ce2081a2f",
            "dToken": "0x176808047cc9b7a2c9ae202c593ed42ddd7c0d13",
            "sdToken": "0x34441ffd1948e49dc7a607882d0c38efd0083815",
            "liquidationThreshold": 0.57
        },
        "0xa693b19d2931d498c5b318df961919bb4aee87a5": {
            "tToken": "0xc2e2152647f4c26028482efaf64b2aa28779efc4",
            "dToken": "0xaf32001cf2e66c4c3af4205f6ea77112aa4160fe",
            "sdToken": "0x7fdbfb0412700d94403c42ca3caeeea183f07b26",
            "liquidationThreshold": 0.0
        },
        "0x4e3fbd56cd56c3e72c1403e103b45db9da5b9d2b": {
            "tToken": "0x952749e07d7157bb9644a894dfaf3bad5ef6d918",
            "dToken": "0x4ae5e4409c6dbc84a00f9f89e4ba096603fb7d50",
            "sdToken": "0xb01eb1ce1da06179136d561766fc2d609c5f55eb",
            "liquidationThreshold": 0.45
        },
        "0x111111111117dc0aa78b770fa6a738034120c302": {
            "tToken": "0xb29130cbcc3f791f077eade0266168e808e5151e",
            "dToken": "0xd7896c1b9b4455aff31473908eb15796ad2295da",
            "sdToken": "0x1278d6ed804d59d2d18a5aa5638dfd591a79af0a",
            "liquidationThreshold": 0.5
        },
        "0x5f98805a4e8be255a32880fdec7f6728c6568ba0": {
            "tToken": "0xce1871f791548600cb59efbeffc9c38719142079",
            "dToken": "0x411066489ab40442d6fc215ad7c64224120d33f2",
            "sdToken": "0x39f010127274b2dbdb770b45e1de54d974974526",
            "liquidationThreshold": 0.0
        }
    }
}
